"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isUseSimpleSourceMap = exports.isUseSourceMap = exports.createRawModuleRuleUses = void 0;
const assert_1 = __importDefault(require("assert"));
const loader_runner_1 = require("../loader-runner");
const BUILTIN_LOADER_PREFIX = "builtin:";
function createRawModuleRuleUses(uses, path, options) {
    const normalizeRuleSetUseItem = (item) => typeof item === "string" ? { loader: item } : item;
    const allUses = Array.isArray(uses)
        ? [...uses].map(normalizeRuleSetUseItem)
        : [normalizeRuleSetUseItem(uses)];
    return createRawModuleRuleUsesImpl(allUses, path, options);
}
exports.createRawModuleRuleUses = createRawModuleRuleUses;
function createRawModuleRuleUsesImpl(uses, path, options) {
    if (!uses.length) {
        return [];
    }
    return uses.map((use, index) => {
        if (typeof use.loader === "string" &&
            use.loader.startsWith(BUILTIN_LOADER_PREFIX)) {
            return createBuiltinUse(use);
        }
        return {
            jsLoader: {
                identifier: resolveStringifyLoaders(use, `${path}[${index}]`, options.compiler)
            }
        };
    });
}
function resolveStringifyLoaders(use, path, compiler) {
    const obj = (0, loader_runner_1.parsePathQueryFragment)(use.loader);
    obj.path = require.resolve(obj.path, {
        paths: [compiler.context]
    });
    let ident = null;
    if (use.options === null)
        obj.query = "";
    else if (use.options === undefined)
        obj.query = "";
    else if (typeof use.options === "string")
        obj.query = "?" + use.options;
    else if (use.ident)
        obj.query = "??" + (ident = use.ident);
    else if (typeof use.options === "object" && use.options.ident)
        obj.query = "??" + (ident = use.options.ident);
    else if (typeof use.options === "object")
        obj.query = "??" + (ident = path);
    else
        obj.query = "?" + JSON.stringify(use.options);
    if (ident) {
        if (typeof use.options === "object") {
            compiler.ruleSet.references.set(ident, use.options);
        }
    }
    return obj.path + obj.query + obj.fragment;
}
function createBuiltinUse(use) {
    var _a;
    (0, assert_1.default)(typeof use.loader === "string" &&
        use.loader.startsWith(BUILTIN_LOADER_PREFIX));
    if (use.loader === `${BUILTIN_LOADER_PREFIX}sass-loader`) {
        ((_a = use.options) !== null && _a !== void 0 ? _a : (use.options = {})).__exePath = require.resolve(`sass-embedded-${process.platform}-${process.arch}/dart-sass-embedded/dart-sass-embedded${process.platform === "win32" ? ".bat" : ""}`);
    }
    return {
        builtinLoader: use.loader,
        options: JSON.stringify(use.options)
    };
}
function isUseSourceMap(devtool) {
    return (devtool.includes("source-map") &&
        (devtool.includes("module") || !devtool.includes("cheap")));
}
exports.isUseSourceMap = isUseSourceMap;
function isUseSimpleSourceMap(devtool) {
    return devtool.includes("source-map") && !isUseSourceMap(devtool);
}
exports.isUseSimpleSourceMap = isUseSimpleSourceMap;
