"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.entry = void 0;
const zod_1 = require("zod");
const output_1 = require("./output");
const entryItem = zod_1.z
    .string()
    .min(1)
    .describe("The string is resolved to a module which is loaded upon startup.")
    .or(zod_1.z.string().min(1).array().min(1));
const entryDescription = zod_1.z
    .object({
    import: entryItem,
    runtime: zod_1.z.literal(false).or(zod_1.z.string().min(1)).optional(),
    publicPath: (0, output_1.publicPath)().optional(),
    baseUri: zod_1.z.string().optional(),
    chunkLoading: zod_1.z
        .literal(false)
        .or(zod_1.z
        .enum(["jsonp", "require", "async-node", "import", "import-scripts"])
        .or(zod_1.z.string())
        .optional()),
    asyncChunks: zod_1.z.boolean().optional(),
    wasmLoading: zod_1.z
        .literal(false)
        .or(zod_1.z.enum(["fetch-streaming", "fetch", "async-node"]))
        .optional(),
    filename: (0, output_1.filename)().optional()
})
    .strict();
const entryObject = zod_1.z.record(entryItem.or(entryDescription));
function entry() {
    return entryItem.or(entryObject);
}
exports.entry = entry;
