"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configSchema = void 0;
const zod_1 = require("zod");
const entry_1 = require("./entry");
const experiments_1 = require("./experiments");
const externals_1 = require("./externals");
const externals_type_1 = require("./externals-type");
const externals_presets_1 = require("./externals-presets");
const infrastructure_logging_1 = require("./infrastructure-logging");
const node_1 = require("./node");
const builtins_1 = require("./builtins");
const watch_options_1 = require("./watch-options");
const target_1 = require("./target");
const stats_1 = require("./stats");
const snapshot_1 = require("./snapshot");
const output_1 = require("./output");
const devtool_1 = require("./devtool");
const optimization_1 = require("./optimization");
const resolve_1 = require("./resolve");
const plugins_1 = require("./plugins");
function configSchema() {
    return zod_1.z
        .object({
        target: (0, target_1.target)().optional(),
        mode: zod_1.z.enum(["development", "production", "none"]).optional(),
        entry: (0, entry_1.entry)().optional(),
        experiments: (0, experiments_1.experiments)().optional(),
        externals: (0, externals_1.externals)().optional(),
        externalsType: (0, externals_type_1.externalsType)().optional(),
        externalsPresets: (0, externals_presets_1.externalsPresets)().optional(),
        infrastructureLogging: (0, infrastructure_logging_1.infrastructureLogging)().optional(),
        cache: zod_1.z.boolean().optional(),
        context: zod_1.z.string().optional(),
        dependencies: zod_1.z.string().array().optional(),
        devtool: (0, devtool_1.devtool)().optional(),
        node: (0, node_1.node)().optional(),
        ignoreWarnings: zod_1.z.instanceof(RegExp).or(zod_1.z.function()).array().optional(),
        watchOptions: (0, watch_options_1.watchOptions)().optional(),
        watch: zod_1.z.boolean().optional(),
        stats: (0, stats_1.stats)().optional(),
        snapshot: (0, snapshot_1.snapshot)().optional(),
        optimization: (0, optimization_1.optimization)().optional(),
        resolve: (0, resolve_1.resolve)().optional(),
        plugins: (0, plugins_1.plugins)().optional(),
        // TODO(hyf0): what's the usage of this?
        name: zod_1.z.string().optional(),
        // TODO
        devServer: zod_1.z.object({}).optional(),
        output: (0, output_1.output)().optional(),
        builtins: (0, builtins_1.builtins)().optional(),
        module: zod_1.z.any().optional()
    })
        .strict();
}
exports.configSchema = configSchema;
