"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.splitChunks = void 0;
const zod_1 = require("zod");
function chunks() {
    return zod_1.z.enum(["initial", "async", "all"]).or(zod_1.z.instanceof(RegExp));
}
function name() {
    return zod_1.z.string().or(zod_1.z.literal(false));
}
const sharedCacheGroupConfigPart = {
    chunks: chunks().optional(),
    minChunks: zod_1.z.number().optional(),
    name: name().optional(),
    minSize: zod_1.z.number().optional(),
    maxSize: zod_1.z.number().optional(),
    maxAsyncSize: zod_1.z.number().optional(),
    maxInitialSize: zod_1.z.number().optional()
};
const cacheGroupOptions = zod_1.z.strictObject({
    test: zod_1.z.instanceof(RegExp).optional(),
    priority: zod_1.z.number().optional(),
    enforce: zod_1.z.boolean().optional(),
    reuseExistingChunk: zod_1.z.boolean().optional(),
    type: zod_1.z.string().or(zod_1.z.instanceof(RegExp)).optional(),
    idHint: zod_1.z.string().optional(),
    ...sharedCacheGroupConfigPart
});
function splitChunks() {
    return zod_1.z.literal(false).or(
    // We use loose object here to prevent breaking change on config
    zod_1.z.object({
        cacheGroups: zod_1.z.record(zod_1.z.literal(false).or(cacheGroupOptions)).optional(),
        maxAsyncRequests: zod_1.z.number().optional(),
        maxInitialRequests: zod_1.z.number().optional(),
        fallbackCacheGroup: zod_1.z
            .strictObject({
            chunks: chunks().optional(),
            minSize: zod_1.z.number().optional(),
            maxSize: zod_1.z.number().optional(),
            maxAsyncSize: zod_1.z.number().optional(),
            maxInitialSize: zod_1.z.number().optional()
        })
            .optional(),
        ...sharedCacheGroupConfigPart
    }));
}
exports.splitChunks = splitChunks;
