"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.output = exports.filename = exports.publicPath = void 0;
const zod_1 = require("zod");
function chunkLoadingType() {
    return zod_1.z
        .enum(["jsonp", "import-scripts", "require", "async-node", "import"])
        .or(zod_1.z.string());
}
function chunkLoading() {
    return zod_1.z.literal(false).or(chunkLoadingType());
}
function wasmLoadingType() {
    return zod_1.z.enum(["...", "fetch-streaming", "fetch", "async-node"]);
}
function wasmLoading() {
    return zod_1.z.literal(false).or(wasmLoadingType());
}
function publicPath() {
    return zod_1.z.literal("auto").or(zod_1.z.string());
}
exports.publicPath = publicPath;
function filename() {
    return zod_1.z.string();
}
exports.filename = filename;
function workerPublicPath() {
    return zod_1.z.string();
}
function libraryType() {
    return zod_1.z.enum([
        "...",
        "var",
        "module",
        "assign",
        "assign-properties",
        "this",
        "window",
        "self",
        "global",
        "commonjs",
        "commonjs2",
        "commonjs-module",
        "commonjs-static",
        "amd",
        "amd-require",
        "umd",
        "umd2",
        "jsonp",
        "system"
    ]);
}
const umdNamedDefine = zod_1.z.boolean();
const auxiliaryComment = zod_1.z.string().or(zod_1.z.strictObject({
    amd: zod_1.z.string().optional(),
    commonjs: zod_1.z.string().optional(),
    commonjs2: zod_1.z.string().optional(),
    root: zod_1.z.string().optional()
}));
const libraryName = zod_1.z
    .string()
    .or(zod_1.z.string().array())
    .or(zod_1.z.strictObject({
    amd: zod_1.z.string().optional(),
    commonjs: zod_1.z.string().optional(),
    root: zod_1.z.string().or(zod_1.z.string().array()).optional()
}));
const libraryOptions = zod_1.z.strictObject({
    auxiliaryComment: auxiliaryComment.optional(),
    export: zod_1.z.string().array().or(zod_1.z.string()).optional(),
    name: libraryName.optional(),
    type: libraryType().optional(),
    umdNamedDefine: umdNamedDefine.optional()
});
function output() {
    return zod_1.z.strictObject({
        iife: zod_1.z.boolean().optional(),
        clean: zod_1.z.boolean().optional(),
        assetModuleFilename: zod_1.z.string().optional(),
        auxiliaryComment: auxiliaryComment.optional(),
        chunkFormat: zod_1.z
            .enum(["array-push", "commonjs", "module"])
            .or(zod_1.z.literal(false))
            .optional(),
        chunkLoading: chunkLoading().optional(),
        enabledChunkLoadingTypes: chunkLoadingType().array().optional(),
        chunkFilename: zod_1.z.string().optional(),
        cssChunkFilename: zod_1.z.string().optional(),
        cssFilename: zod_1.z.string().optional(),
        hotUpdateChunkFilename: zod_1.z.string().optional(),
        hotUpdateMainFilename: zod_1.z.string().optional(),
        webassemblyModuleFilename: zod_1.z.string().optional(),
        hashSalt: zod_1.z.string().optional(),
        filename: filename().optional(),
        sourceMapFilename: zod_1.z.string().optional(),
        importFunctionName: zod_1.z.string().optional(),
        publicPath: publicPath().optional(),
        uniqueName: zod_1.z.string().optional(),
        path: zod_1.z.string().optional(),
        crossOriginLoading: zod_1.z
            .literal(false)
            .or(zod_1.z.enum(["anonymous", "use-credentials"]))
            .optional(),
        enabledWasmLoadingTypes: wasmLoadingType().array().optional(),
        wasmLoading: wasmLoading().optional(),
        enabledLibraryTypes: libraryType().or(libraryType().array()).optional(),
        globalObject: zod_1.z.string().min(1).optional(),
        libraryExport: zod_1.z.string().min(1).or(zod_1.z.string().min(1).array()).optional(),
        libraryTarget: libraryType().optional(),
        hashFunction: zod_1.z.string().or(zod_1.z.function()).optional(),
        // TODO(hyf0)
        module: zod_1.z.any().optional(),
        strictModuleErrorHandling: zod_1.z.boolean().optional(),
        umdNamedDefine: umdNamedDefine.optional(),
        chunkLoadingGlobal: zod_1.z.string().optional(),
        trustedTypes: zod_1.z
            .literal(true)
            .or(zod_1.z.string())
            .or(zod_1.z.strictObject({
            policyName: zod_1.z.string().optional()
        }))
            .optional(),
        hashDigest: zod_1.z.string().optional(),
        hashDigestLength: zod_1.z.number().optional(),
        library: libraryName.or(libraryOptions).optional(),
        asyncChunks: zod_1.z.boolean().optional(),
        workerChunkLoading: chunkLoading().optional(),
        workerWasmLoading: wasmLoading().optional(),
        workerPublicPath: workerPublicPath().optional()
    });
}
exports.output = output;
