"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _Stats_inner;
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeStatsPreset = exports.Stats = void 0;
class Stats {
    constructor(compilation) {
        _Stats_inner.set(this, void 0);
        __classPrivateFieldSet(this, _Stats_inner, compilation.__internal_getInner().getStats(), "f");
        this.compilation = compilation;
    }
    get hash() {
        return this.compilation.hash;
    }
    hasErrors() {
        return __classPrivateFieldGet(this, _Stats_inner, "f").getErrors().length > 0;
    }
    hasWarnings() {
        return __classPrivateFieldGet(this, _Stats_inner, "f").getWarnings().length > 0;
    }
    toJson(opts, forToString) {
        var _a, _b;
        const options = this.compilation.createStatsOptions(opts, {
            forToString
        });
        let obj = {};
        if (options.hash) {
            obj.hash = __classPrivateFieldGet(this, _Stats_inner, "f").getHash();
        }
        if (options.version) {
            const { version, webpackVersion } = require("../package.json");
            obj.version = webpackVersion;
            obj.rspackVersion = version;
        }
        if (options.timings) {
            obj.time = this.compilation.endTime - this.compilation.startTime;
        }
        if (options.builtAt) {
            obj.builtAt = this.compilation.endTime;
        }
        if (options.publicPath) {
            obj.publicPath = this.compilation.outputOptions.publicPath;
        }
        if (options.outputPath) {
            obj.outputPath = this.compilation.outputOptions.path;
        }
        if (options.assets) {
            const { assets, assetsByChunkName } = __classPrivateFieldGet(this, _Stats_inner, "f").getAssets();
            obj.assets = assets;
            obj.assetsByChunkName = assetsByChunkName.reduce((acc, cur) => {
                acc[cur.name] = cur.files;
                return acc;
            }, {});
        }
        if (options.chunks) {
            obj.chunks = __classPrivateFieldGet(this, _Stats_inner, "f").getChunks(options.chunkModules, options.chunkRelations, options.reasons, options.moduleAssets, options.nestedModules);
        }
        if (options.modules) {
            obj.modules = __classPrivateFieldGet(this, _Stats_inner, "f").getModules(options.reasons, options.moduleAssets, options.nestedModules);
        }
        if (options.entrypoints) {
            obj.entrypoints = __classPrivateFieldGet(this, _Stats_inner, "f")
                .getEntrypoints()
                .reduce((acc, cur) => {
                acc[cur.name] = cur;
                return acc;
            }, {});
        }
        if (options.chunkGroups) {
            obj.namedChunkGroups = __classPrivateFieldGet(this, _Stats_inner, "f")
                .getNamedChunkGroups()
                .reduce((acc, cur) => {
                acc[cur.name] = cur;
                return acc;
            }, {});
        }
        if (options.errors) {
            obj.errors = __classPrivateFieldGet(this, _Stats_inner, "f").getErrors();
        }
        if (options.errorsCount) {
            obj.errorsCount = ((_a = obj.errors) !== null && _a !== void 0 ? _a : __classPrivateFieldGet(this, _Stats_inner, "f").getErrors()).length;
        }
        if (options.warnings) {
            obj.warnings = __classPrivateFieldGet(this, _Stats_inner, "f").getWarnings();
        }
        if (options.warningsCount) {
            obj.warningsCount = ((_b = obj.warnings) !== null && _b !== void 0 ? _b : __classPrivateFieldGet(this, _Stats_inner, "f").getWarnings()).length;
        }
        if (obj.modules && forToString) {
            obj.filteredModules = obj.modules.length - 15;
            obj.modules = obj.modules.slice(0, 15);
        }
        return obj;
    }
    toString(opts) {
        const options = this.compilation.createStatsOptions(opts, {
            forToString: true
        });
        const obj = this.toJson(options, true);
        const statsPrinter = this.compilation.createStatsPrinter(options);
        const result = statsPrinter.print("compilation", obj);
        return result === undefined ? "" : result;
    }
}
exports.Stats = Stats;
_Stats_inner = new WeakMap();
function normalizeStatsPreset(options) {
    if (typeof options === "boolean" || typeof options === "string")
        return presetToOptions(options);
    else if (!options)
        return {};
    else {
        let obj = { ...presetToOptions(options.preset), ...options };
        delete obj.preset;
        return obj;
    }
}
exports.normalizeStatsPreset = normalizeStatsPreset;
function presetToOptions(name) {
    const pn = (typeof name === "string" && name.toLowerCase()) || name;
    switch (pn) {
        case "none":
            return {
                all: false
            };
        case "verbose":
            return {
                all: true
            };
        case "errors-only":
            return {
                all: false,
                errors: true,
                errorsCount: true
                // TODO: moduleTrace: true,
                // TODO: logging: "error"
            };
        case "errors-warnings":
            return {
                all: false,
                errors: true,
                errorsCount: true,
                warnings: true,
                warningsCount: true
                // TODO: logging: "warn"
            };
        default:
            return {};
    }
}
